package DBI::Easy::Test::Address;

use strict;

use DBI::Easy::Record;
use base qw(DBI::Easy::Record);

#sub _init_last {
#	my $self = shift;
#	
#	$self->is_related_to (
#		'contacts', 'DBI::Easy::Test::Contact::Collection'
#	);
#	
#	$self->is_related_to (
#		'passport', 'DBI::Easy::Test::Passport'
#	);
#	
#}

1;